==> qDecoder-6.0.3.tgz: share/examples/qDecoder/streamedit.c <==
/************************************************************************
qDecoder - C/C++ CGI Library                      http://www.qDecoder.org

Copyright (C) 1999,2000 Hongik Internet, Inc.
Copyright (C) 1998 Nobreak Technologies, Inc.
Copyright (C) 1996,1997 Seung-young Kim.

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

Copyright Disclaimer:
  Hongik Internet, Inc., hereby disclaims all copyright interest.
  President, Christopher Roh, 6 April 2000

  Nobreak Technologies, Inc., hereby disclaims all copyright interest.
  President, Yoon Cho, 6 April 2000

  Seung-young Kim, hereby disclaims all copyright interest.
  Author, Seung-young Kim, 6 April 2000

Author:
  Seung-young Kim <nobreak@hongik.com>
  5th Fl., Daewoong Bldg., 689-4, Yoksam, Kangnam, Seoul, Korea 135-080
  Tel: +82-2-562-8988, Fax: +82-2-562-8987
************************************************************************/

#include "qDecoder.h"

#define SOURCE		"streamedit.html.in"

int main(void) {
  char *arg[2 + 1];
  char buf[2][256];
  char *name, *hobby;

  qContentType("text/html");

  if((name = qValue("name")) == NULL || (hobby = qValue("hobby")) == NULL) {
    qError("Query fetch fail.");
  }

  sprintf(buf[0], "s/${NAME}/%s/", name);
  sprintf(buf[1], "s/${HOBBY}/%s/", hobby);
  arg[0] = buf[0];
  arg[1] = buf[1];
  arg[2] = NULL;

  if(qSedFile(SOURCE, stdout, arg) == 0) qError("File(%s) not found.", SOURCE);
  return 0;
}

==> qDecoder-7.0.tgz: share/examples/qDecoder/streamedit.c <==
/************************************************************************
qDecoder - Web Application Interface for C/C++    http://www.qDecoder.org

Copyright (C) 2001 The qDecoder Project.
Copyright (C) 1999,2000 Hongik Internet, Inc.
Copyright (C) 1998 Nobreak Technologies, Inc.
Copyright (C) 1996,1997 Seung-young Kim.

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

Copyright Disclaimer:
  Hongik Internet, Inc., hereby disclaims all copyright interest.
  President, Christopher Roh, 6 April 2000

  Nobreak Technologies, Inc., hereby disclaims all copyright interest.
  President, Yoon Cho, 6 April 2000

  Seung-young Kim, hereby disclaims all copyright interest.
  Author, Seung-young Kim, 6 April 2000
************************************************************************/

#include "qDecoder.h"

#define SOURCE		"streamedit.html.in"

int main(void) {
  Q_Entry *args;
  char *name, *hobby;

  qContentType("text/html");

  name = qValueDefault("Not Found", "name");
  hobby = qValueDefault("Not Found", "hobby");

  args = NULL;
  args = qSedArgAdd(args, "${NAME}", name);
  args = qSedArgAdd(args, "${HOBBY}", hobby);
  if(qSedFile(args, SOURCE, stdout) == 0) qError("File(%s) not found.", SOURCE);
  qSedArgFree(args);

  return 0;
}
